## Usage

```python3
from Neural_Network import NeuralNetwork

# Create a Neural Network
inputs = 2
output_neurons = 1
hidden_layers = 2
each_hidden_nodes = [2, 3]
network = NeuralNetwork(inputs, hidden_layers, output_neurons, each_hidden_nodes)
```
